@@ -37,3 +37,9 @@ def load_image(filename,local=False):
     return result
 
 
+
+# dividir dataset en training y testing de forma aleatoria    
+def dividir_train_test(X, Y, test_size= 0.2):
+    from sklearn.model_selection import train_test_split
+    X_train, X_test, Y_train, Y_test = train_test_split(X, Y, test_size= test_size)
+    return X_train, X_test, Y_train, Y_test
